# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NetworkArgs', 'Network']

@pulumi.input_type
class NetworkArgs:
    def __init__(__self__, *,
                 cidr: pulumi.Input[_builtins.str],
                 region: pulumi.Input[_builtins.str],
                 aws_availability_zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input['NetworkTimeoutsArgs']] = None):
        """
        The set of arguments for constructing a Network resource.
        :param pulumi.Input[_builtins.str] cidr: The CIDR range of the Network.
        :param pulumi.Input[_builtins.str] region: The Vercel region in which the Network exists.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] aws_availability_zone_ids: The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        :param pulumi.Input[_builtins.str] name: The name of the network.
        :param pulumi.Input[_builtins.str] team_id: The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        """
        pulumi.set(__self__, "cidr", cidr)
        pulumi.set(__self__, "region", region)
        if aws_availability_zone_ids is not None:
            pulumi.set(__self__, "aws_availability_zone_ids", aws_availability_zone_ids)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)

    @_builtins.property
    @pulumi.getter
    def cidr(self) -> pulumi.Input[_builtins.str]:
        """
        The CIDR range of the Network.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cidr", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Input[_builtins.str]:
        """
        The Vercel region in which the Network exists.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="awsAvailabilityZoneIds")
    def aws_availability_zone_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        """
        return pulumi.get(self, "aws_availability_zone_ids")

    @aws_availability_zone_ids.setter
    def aws_availability_zone_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "aws_availability_zone_ids", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the network.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['NetworkTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['NetworkTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)


@pulumi.input_type
class _NetworkState:
    def __init__(__self__, *,
                 aws_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 aws_availability_zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 aws_region: Optional[pulumi.Input[_builtins.str]] = None,
                 cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 egress_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input['NetworkTimeoutsArgs']] = None,
                 vpc_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Network resources.
        :param pulumi.Input[_builtins.str] aws_account_id: The ID of the AWS Account in which the network exists.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] aws_availability_zone_ids: The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        :param pulumi.Input[_builtins.str] aws_region: The AWS Region in which the network exists.
        :param pulumi.Input[_builtins.str] cidr: The CIDR range of the Network.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] egress_ip_addresses: The egress IP addresses of the Network.
        :param pulumi.Input[_builtins.str] name: The name of the network.
        :param pulumi.Input[_builtins.str] region: The Vercel region in which the Network exists.
        :param pulumi.Input[_builtins.str] status: The status of the Network.
        :param pulumi.Input[_builtins.str] team_id: The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        :param pulumi.Input[_builtins.str] vpc_id: The ID of the AWS VPC which hosts the network.
        """
        if aws_account_id is not None:
            pulumi.set(__self__, "aws_account_id", aws_account_id)
        if aws_availability_zone_ids is not None:
            pulumi.set(__self__, "aws_availability_zone_ids", aws_availability_zone_ids)
        if aws_region is not None:
            pulumi.set(__self__, "aws_region", aws_region)
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if egress_ip_addresses is not None:
            pulumi.set(__self__, "egress_ip_addresses", egress_ip_addresses)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @_builtins.property
    @pulumi.getter(name="awsAccountId")
    def aws_account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the AWS Account in which the network exists.
        """
        return pulumi.get(self, "aws_account_id")

    @aws_account_id.setter
    def aws_account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_account_id", value)

    @_builtins.property
    @pulumi.getter(name="awsAvailabilityZoneIds")
    def aws_availability_zone_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        """
        return pulumi.get(self, "aws_availability_zone_ids")

    @aws_availability_zone_ids.setter
    def aws_availability_zone_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "aws_availability_zone_ids", value)

    @_builtins.property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The AWS Region in which the network exists.
        """
        return pulumi.get(self, "aws_region")

    @aws_region.setter
    def aws_region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "aws_region", value)

    @_builtins.property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The CIDR range of the Network.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cidr", value)

    @_builtins.property
    @pulumi.getter(name="egressIpAddresses")
    def egress_ip_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The egress IP addresses of the Network.
        """
        return pulumi.get(self, "egress_ip_addresses")

    @egress_ip_addresses.setter
    def egress_ip_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "egress_ip_addresses", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the network.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Vercel region in which the Network exists.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the Network.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['NetworkTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['NetworkTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)

    @_builtins.property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the AWS VPC which hosts the network.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("vercel:index/network:Network")
class Network(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_availability_zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input[Union['NetworkTimeoutsArgs', 'NetworkTimeoutsArgsDict']]] = None,
                 __props__=None):
        """
        Provides a Network resource.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] aws_availability_zone_ids: The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        :param pulumi.Input[_builtins.str] cidr: The CIDR range of the Network.
        :param pulumi.Input[_builtins.str] name: The name of the network.
        :param pulumi.Input[_builtins.str] region: The Vercel region in which the Network exists.
        :param pulumi.Input[_builtins.str] team_id: The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Network resource.

        :param str resource_name: The name of the resource.
        :param NetworkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_availability_zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 cidr: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input[Union['NetworkTimeoutsArgs', 'NetworkTimeoutsArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkArgs.__new__(NetworkArgs)

            __props__.__dict__["aws_availability_zone_ids"] = aws_availability_zone_ids
            if cidr is None and not opts.urn:
                raise TypeError("Missing required property 'cidr'")
            __props__.__dict__["cidr"] = cidr
            __props__.__dict__["name"] = name
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            __props__.__dict__["team_id"] = team_id
            __props__.__dict__["timeouts"] = timeouts
            __props__.__dict__["aws_account_id"] = None
            __props__.__dict__["aws_region"] = None
            __props__.__dict__["egress_ip_addresses"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["vpc_id"] = None
        super(Network, __self__).__init__(
            'vercel:index/network:Network',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aws_account_id: Optional[pulumi.Input[_builtins.str]] = None,
            aws_availability_zone_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            aws_region: Optional[pulumi.Input[_builtins.str]] = None,
            cidr: Optional[pulumi.Input[_builtins.str]] = None,
            egress_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            team_id: Optional[pulumi.Input[_builtins.str]] = None,
            timeouts: Optional[pulumi.Input[Union['NetworkTimeoutsArgs', 'NetworkTimeoutsArgsDict']]] = None,
            vpc_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Network':
        """
        Get an existing Network resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] aws_account_id: The ID of the AWS Account in which the network exists.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] aws_availability_zone_ids: The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        :param pulumi.Input[_builtins.str] aws_region: The AWS Region in which the network exists.
        :param pulumi.Input[_builtins.str] cidr: The CIDR range of the Network.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] egress_ip_addresses: The egress IP addresses of the Network.
        :param pulumi.Input[_builtins.str] name: The name of the network.
        :param pulumi.Input[_builtins.str] region: The Vercel region in which the Network exists.
        :param pulumi.Input[_builtins.str] status: The status of the Network.
        :param pulumi.Input[_builtins.str] team_id: The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        :param pulumi.Input[_builtins.str] vpc_id: The ID of the AWS VPC which hosts the network.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkState.__new__(_NetworkState)

        __props__.__dict__["aws_account_id"] = aws_account_id
        __props__.__dict__["aws_availability_zone_ids"] = aws_availability_zone_ids
        __props__.__dict__["aws_region"] = aws_region
        __props__.__dict__["cidr"] = cidr
        __props__.__dict__["egress_ip_addresses"] = egress_ip_addresses
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["status"] = status
        __props__.__dict__["team_id"] = team_id
        __props__.__dict__["timeouts"] = timeouts
        __props__.__dict__["vpc_id"] = vpc_id
        return Network(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="awsAccountId")
    def aws_account_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the AWS Account in which the network exists.
        """
        return pulumi.get(self, "aws_account_id")

    @_builtins.property
    @pulumi.getter(name="awsAvailabilityZoneIds")
    def aws_availability_zone_ids(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        """
        return pulumi.get(self, "aws_availability_zone_ids")

    @_builtins.property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> pulumi.Output[_builtins.str]:
        """
        The AWS Region in which the network exists.
        """
        return pulumi.get(self, "aws_region")

    @_builtins.property
    @pulumi.getter
    def cidr(self) -> pulumi.Output[_builtins.str]:
        """
        The CIDR range of the Network.
        """
        return pulumi.get(self, "cidr")

    @_builtins.property
    @pulumi.getter(name="egressIpAddresses")
    def egress_ip_addresses(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The egress IP addresses of the Network.
        """
        return pulumi.get(self, "egress_ip_addresses")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the network.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The Vercel region in which the Network exists.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the Network.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> pulumi.Output[Optional['outputs.NetworkTimeouts']]:
        return pulumi.get(self, "timeouts")

    @_builtins.property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the AWS VPC which hosts the network.
        """
        return pulumi.get(self, "vpc_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['CustomCertificateArgs', 'CustomCertificate']

@pulumi.input_type
class CustomCertificateArgs:
    def __init__(__self__, *,
                 certificate: pulumi.Input[_builtins.str],
                 certificate_authority_certificate: pulumi.Input[_builtins.str],
                 private_key: pulumi.Input[_builtins.str],
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a CustomCertificate resource.
        :param pulumi.Input[_builtins.str] certificate: The certificate itself. Should be in PEM format.
        :param pulumi.Input[_builtins.str] certificate_authority_certificate: The Certificate Authority root certificate such as one of Let's Encrypt's ISRG root certificates. This will be provided by your certificate issuer and is different to the core certificate. This may be included in their download process or available for download on their website. Should be in PEM format.
        :param pulumi.Input[_builtins.str] private_key: The private key of the Certificate. Should be in PEM format.
        :param pulumi.Input[_builtins.str] team_id: The ID of the team the Custom Certificate should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        pulumi.set(__self__, "certificate", certificate)
        pulumi.set(__self__, "certificate_authority_certificate", certificate_authority_certificate)
        pulumi.set(__self__, "private_key", private_key)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter
    def certificate(self) -> pulumi.Input[_builtins.str]:
        """
        The certificate itself. Should be in PEM format.
        """
        return pulumi.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "certificate", value)

    @_builtins.property
    @pulumi.getter(name="certificateAuthorityCertificate")
    def certificate_authority_certificate(self) -> pulumi.Input[_builtins.str]:
        """
        The Certificate Authority root certificate such as one of Let's Encrypt's ISRG root certificates. This will be provided by your certificate issuer and is different to the core certificate. This may be included in their download process or available for download on their website. Should be in PEM format.
        """
        return pulumi.get(self, "certificate_authority_certificate")

    @certificate_authority_certificate.setter
    def certificate_authority_certificate(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "certificate_authority_certificate", value)

    @_builtins.property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> pulumi.Input[_builtins.str]:
        """
        The private key of the Certificate. Should be in PEM format.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "private_key", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the team the Custom Certificate should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.input_type
class _CustomCertificateState:
    def __init__(__self__, *,
                 certificate: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_authority_certificate: Optional[pulumi.Input[_builtins.str]] = None,
                 private_key: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering CustomCertificate resources.
        :param pulumi.Input[_builtins.str] certificate: The certificate itself. Should be in PEM format.
        :param pulumi.Input[_builtins.str] certificate_authority_certificate: The Certificate Authority root certificate such as one of Let's Encrypt's ISRG root certificates. This will be provided by your certificate issuer and is different to the core certificate. This may be included in their download process or available for download on their website. Should be in PEM format.
        :param pulumi.Input[_builtins.str] private_key: The private key of the Certificate. Should be in PEM format.
        :param pulumi.Input[_builtins.str] team_id: The ID of the team the Custom Certificate should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        if certificate is not None:
            pulumi.set(__self__, "certificate", certificate)
        if certificate_authority_certificate is not None:
            pulumi.set(__self__, "certificate_authority_certificate", certificate_authority_certificate)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter
    def certificate(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The certificate itself. Should be in PEM format.
        """
        return pulumi.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "certificate", value)

    @_builtins.property
    @pulumi.getter(name="certificateAuthorityCertificate")
    def certificate_authority_certificate(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Certificate Authority root certificate such as one of Let's Encrypt's ISRG root certificates. This will be provided by your certificate issuer and is different to the core certificate. This may be included in their download process or available for download on their website. Should be in PEM format.
        """
        return pulumi.get(self, "certificate_authority_certificate")

    @certificate_authority_certificate.setter
    def certificate_authority_certificate(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "certificate_authority_certificate", value)

    @_builtins.property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The private key of the Certificate. Should be in PEM format.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_key", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the team the Custom Certificate should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.type_token("vercel:index/customCertificate:CustomCertificate")
class CustomCertificate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 certificate: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_authority_certificate: Optional[pulumi.Input[_builtins.str]] = None,
                 private_key: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a Custom Certificate Resource, allowing Custom Certificates to be uploaded to Vercel.

        By default, Vercel provides all domains with a custom SSL certificates. However, Enterprise teams can upload their own custom SSL certificate.

        For more detailed information, please see the [Vercel documentation](https://vercel.com/docs/domains/custom-SSL-certificate).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_std as std
        import pulumiverse_vercel as vercel

        example = vercel.CustomCertificate("example",
            private_key=std.index.file(input="private.key")["result"],
            certificate=std.index.file(input="certificate.crt")["result"],
            certificate_authority_certificate=std.index.file(input="ca.crt")["result"])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] certificate: The certificate itself. Should be in PEM format.
        :param pulumi.Input[_builtins.str] certificate_authority_certificate: The Certificate Authority root certificate such as one of Let's Encrypt's ISRG root certificates. This will be provided by your certificate issuer and is different to the core certificate. This may be included in their download process or available for download on their website. Should be in PEM format.
        :param pulumi.Input[_builtins.str] private_key: The private key of the Certificate. Should be in PEM format.
        :param pulumi.Input[_builtins.str] team_id: The ID of the team the Custom Certificate should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CustomCertificateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Custom Certificate Resource, allowing Custom Certificates to be uploaded to Vercel.

        By default, Vercel provides all domains with a custom SSL certificates. However, Enterprise teams can upload their own custom SSL certificate.

        For more detailed information, please see the [Vercel documentation](https://vercel.com/docs/domains/custom-SSL-certificate).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_std as std
        import pulumiverse_vercel as vercel

        example = vercel.CustomCertificate("example",
            private_key=std.index.file(input="private.key")["result"],
            certificate=std.index.file(input="certificate.crt")["result"],
            certificate_authority_certificate=std.index.file(input="ca.crt")["result"])
        ```

        :param str resource_name: The name of the resource.
        :param CustomCertificateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomCertificateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 certificate: Optional[pulumi.Input[_builtins.str]] = None,
                 certificate_authority_certificate: Optional[pulumi.Input[_builtins.str]] = None,
                 private_key: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomCertificateArgs.__new__(CustomCertificateArgs)

            if certificate is None and not opts.urn:
                raise TypeError("Missing required property 'certificate'")
            __props__.__dict__["certificate"] = certificate
            if certificate_authority_certificate is None and not opts.urn:
                raise TypeError("Missing required property 'certificate_authority_certificate'")
            __props__.__dict__["certificate_authority_certificate"] = certificate_authority_certificate
            if private_key is None and not opts.urn:
                raise TypeError("Missing required property 'private_key'")
            __props__.__dict__["private_key"] = None if private_key is None else pulumi.Output.secret(private_key)
            __props__.__dict__["team_id"] = team_id
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["privateKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(CustomCertificate, __self__).__init__(
            'vercel:index/customCertificate:CustomCertificate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            certificate: Optional[pulumi.Input[_builtins.str]] = None,
            certificate_authority_certificate: Optional[pulumi.Input[_builtins.str]] = None,
            private_key: Optional[pulumi.Input[_builtins.str]] = None,
            team_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'CustomCertificate':
        """
        Get an existing CustomCertificate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] certificate: The certificate itself. Should be in PEM format.
        :param pulumi.Input[_builtins.str] certificate_authority_certificate: The Certificate Authority root certificate such as one of Let's Encrypt's ISRG root certificates. This will be provided by your certificate issuer and is different to the core certificate. This may be included in their download process or available for download on their website. Should be in PEM format.
        :param pulumi.Input[_builtins.str] private_key: The private key of the Certificate. Should be in PEM format.
        :param pulumi.Input[_builtins.str] team_id: The ID of the team the Custom Certificate should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomCertificateState.__new__(_CustomCertificateState)

        __props__.__dict__["certificate"] = certificate
        __props__.__dict__["certificate_authority_certificate"] = certificate_authority_certificate
        __props__.__dict__["private_key"] = private_key
        __props__.__dict__["team_id"] = team_id
        return CustomCertificate(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def certificate(self) -> pulumi.Output[_builtins.str]:
        """
        The certificate itself. Should be in PEM format.
        """
        return pulumi.get(self, "certificate")

    @_builtins.property
    @pulumi.getter(name="certificateAuthorityCertificate")
    def certificate_authority_certificate(self) -> pulumi.Output[_builtins.str]:
        """
        The Certificate Authority root certificate such as one of Let's Encrypt's ISRG root certificates. This will be provided by your certificate issuer and is different to the core certificate. This may be included in their download process or available for download on their website. Should be in PEM format.
        """
        return pulumi.get(self, "certificate_authority_certificate")

    @_builtins.property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> pulumi.Output[_builtins.str]:
        """
        The private key of the Certificate. Should be in PEM format.
        """
        return pulumi.get(self, "private_key")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the team the Custom Certificate should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetDomainConfigResult',
    'AwaitableGetDomainConfigResult',
    'get_domain_config',
    'get_domain_config_output',
]

@pulumi.output_type
class GetDomainConfigResult:
    """
    A collection of values returned by getDomainConfig.
    """
    def __init__(__self__, domain=None, id=None, project_id_or_name=None, recommended_cname=None, recommended_ipv4s=None, team_id=None):
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_id_or_name and not isinstance(project_id_or_name, str):
            raise TypeError("Expected argument 'project_id_or_name' to be a str")
        pulumi.set(__self__, "project_id_or_name", project_id_or_name)
        if recommended_cname and not isinstance(recommended_cname, str):
            raise TypeError("Expected argument 'recommended_cname' to be a str")
        pulumi.set(__self__, "recommended_cname", recommended_cname)
        if recommended_ipv4s and not isinstance(recommended_ipv4s, list):
            raise TypeError("Expected argument 'recommended_ipv4s' to be a list")
        pulumi.set(__self__, "recommended_ipv4s", recommended_ipv4s)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> _builtins.str:
        """
        The domain name to get configuration for.
        """
        return pulumi.get(self, "domain")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="projectIdOrName")
    def project_id_or_name(self) -> _builtins.str:
        """
        The project ID or name associated with the domain.
        """
        return pulumi.get(self, "project_id_or_name")

    @_builtins.property
    @pulumi.getter(name="recommendedCname")
    def recommended_cname(self) -> _builtins.str:
        """
        The recommended CNAME value for the domain.
        """
        return pulumi.get(self, "recommended_cname")

    @_builtins.property
    @pulumi.getter(name="recommendedIpv4s")
    def recommended_ipv4s(self) -> Sequence[_builtins.str]:
        """
        The recommended IPv4 values for the domain.
        """
        return pulumi.get(self, "recommended_ipv4s")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The ID of the team the domain config exists under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")


class AwaitableGetDomainConfigResult(GetDomainConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDomainConfigResult(
            domain=self.domain,
            id=self.id,
            project_id_or_name=self.project_id_or_name,
            recommended_cname=self.recommended_cname,
            recommended_ipv4s=self.recommended_ipv4s,
            team_id=self.team_id)


def get_domain_config(domain: Optional[_builtins.str] = None,
                      project_id_or_name: Optional[_builtins.str] = None,
                      team_id: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDomainConfigResult:
    """
    Provides domain configuration information for a Vercel project.

    This data source returns configuration details for a domain associated with a specific project,
    including recommended CNAME and IPv4 values.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws
    import pulumi_vercel as vercel
    import pulumiverse_vercel as vercel

    my_awesome_project = vercel.Project("my_awesome_project", name="my-awesome-project")
    # 
    # "vercel_domain_config" Usage
    # 
    example_com = vercel.get_domain_config_output(domain="example.com",
        project_id_or_name=my_awesome_project.id)
    www_example_com = vercel.get_domain_config_output(domain="www.example.com",
        project_id_or_name=my_awesome_project.id)
    #
    # External DNS provider example
    # 
    example_com_a = aws.index.Route53Record("example_com_a",
        zone_id=...zone_id_from_somewhere...,
        name=example_com.domain,
        type=A,
        ttl=300,
        records=example_com.recommended_ipv4s)
    www_example_com_cname = aws.index.Route53Record("www_example_com_cname",
        zone_id=...zone_id_from_somewhere...,
        name=www_example_com.domain,
        type=CNAME,
        ttl=300,
        records=[www_example_com.recommended_cname])
    ```


    :param _builtins.str domain: The domain name to get configuration for.
    :param _builtins.str project_id_or_name: The project ID or name associated with the domain.
    :param _builtins.str team_id: The ID of the team the domain config exists under. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['domain'] = domain
    __args__['projectIdOrName'] = project_id_or_name
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getDomainConfig:getDomainConfig', __args__, opts=opts, typ=GetDomainConfigResult).value

    return AwaitableGetDomainConfigResult(
        domain=pulumi.get(__ret__, 'domain'),
        id=pulumi.get(__ret__, 'id'),
        project_id_or_name=pulumi.get(__ret__, 'project_id_or_name'),
        recommended_cname=pulumi.get(__ret__, 'recommended_cname'),
        recommended_ipv4s=pulumi.get(__ret__, 'recommended_ipv4s'),
        team_id=pulumi.get(__ret__, 'team_id'))
def get_domain_config_output(domain: Optional[pulumi.Input[_builtins.str]] = None,
                             project_id_or_name: Optional[pulumi.Input[_builtins.str]] = None,
                             team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDomainConfigResult]:
    """
    Provides domain configuration information for a Vercel project.

    This data source returns configuration details for a domain associated with a specific project,
    including recommended CNAME and IPv4 values.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws
    import pulumi_vercel as vercel
    import pulumiverse_vercel as vercel

    my_awesome_project = vercel.Project("my_awesome_project", name="my-awesome-project")
    # 
    # "vercel_domain_config" Usage
    # 
    example_com = vercel.get_domain_config_output(domain="example.com",
        project_id_or_name=my_awesome_project.id)
    www_example_com = vercel.get_domain_config_output(domain="www.example.com",
        project_id_or_name=my_awesome_project.id)
    #
    # External DNS provider example
    # 
    example_com_a = aws.index.Route53Record("example_com_a",
        zone_id=...zone_id_from_somewhere...,
        name=example_com.domain,
        type=A,
        ttl=300,
        records=example_com.recommended_ipv4s)
    www_example_com_cname = aws.index.Route53Record("www_example_com_cname",
        zone_id=...zone_id_from_somewhere...,
        name=www_example_com.domain,
        type=CNAME,
        ttl=300,
        records=[www_example_com.recommended_cname])
    ```


    :param _builtins.str domain: The domain name to get configuration for.
    :param _builtins.str project_id_or_name: The project ID or name associated with the domain.
    :param _builtins.str team_id: The ID of the team the domain config exists under. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['domain'] = domain
    __args__['projectIdOrName'] = project_id_or_name
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getDomainConfig:getDomainConfig', __args__, opts=opts, typ=GetDomainConfigResult)
    return __ret__.apply(lambda __response__: GetDomainConfigResult(
        domain=pulumi.get(__response__, 'domain'),
        id=pulumi.get(__response__, 'id'),
        project_id_or_name=pulumi.get(__response__, 'project_id_or_name'),
        recommended_cname=pulumi.get(__response__, 'recommended_cname'),
        recommended_ipv4s=pulumi.get(__response__, 'recommended_ipv4s'),
        team_id=pulumi.get(__response__, 'team_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['MicrofrontendGroupMembershipArgs', 'MicrofrontendGroupMembership']

@pulumi.input_type
class MicrofrontendGroupMembershipArgs:
    def __init__(__self__, *,
                 microfrontend_group_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 default_route: Optional[pulumi.Input[_builtins.str]] = None,
                 route_observability_to_this_project: Optional[pulumi.Input[_builtins.bool]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a MicrofrontendGroupMembership resource.
        :param pulumi.Input[_builtins.str] microfrontend_group_id: The ID of the microfrontend group.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project.
        :param pulumi.Input[_builtins.str] default_route: The default route for the project. Used for the screenshot of deployments.
        :param pulumi.Input[_builtins.bool] route_observability_to_this_project: Whether the project is route observability for this project. If dalse, the project will be route observability for all projects to the default project.
        :param pulumi.Input[_builtins.str] team_id: The team ID to add the microfrontend group to. Required when configuring a team resource if a default team has not been set in the provider.
        """
        pulumi.set(__self__, "microfrontend_group_id", microfrontend_group_id)
        pulumi.set(__self__, "project_id", project_id)
        if default_route is not None:
            pulumi.set(__self__, "default_route", default_route)
        if route_observability_to_this_project is not None:
            pulumi.set(__self__, "route_observability_to_this_project", route_observability_to_this_project)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter(name="microfrontendGroupId")
    def microfrontend_group_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the microfrontend group.
        """
        return pulumi.get(self, "microfrontend_group_id")

    @microfrontend_group_id.setter
    def microfrontend_group_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "microfrontend_group_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="defaultRoute")
    def default_route(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The default route for the project. Used for the screenshot of deployments.
        """
        return pulumi.get(self, "default_route")

    @default_route.setter
    def default_route(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_route", value)

    @_builtins.property
    @pulumi.getter(name="routeObservabilityToThisProject")
    def route_observability_to_this_project(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the project is route observability for this project. If dalse, the project will be route observability for all projects to the default project.
        """
        return pulumi.get(self, "route_observability_to_this_project")

    @route_observability_to_this_project.setter
    def route_observability_to_this_project(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "route_observability_to_this_project", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The team ID to add the microfrontend group to. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.input_type
class _MicrofrontendGroupMembershipState:
    def __init__(__self__, *,
                 default_route: Optional[pulumi.Input[_builtins.str]] = None,
                 microfrontend_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 route_observability_to_this_project: Optional[pulumi.Input[_builtins.bool]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering MicrofrontendGroupMembership resources.
        :param pulumi.Input[_builtins.str] default_route: The default route for the project. Used for the screenshot of deployments.
        :param pulumi.Input[_builtins.str] microfrontend_group_id: The ID of the microfrontend group.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project.
        :param pulumi.Input[_builtins.bool] route_observability_to_this_project: Whether the project is route observability for this project. If dalse, the project will be route observability for all projects to the default project.
        :param pulumi.Input[_builtins.str] team_id: The team ID to add the microfrontend group to. Required when configuring a team resource if a default team has not been set in the provider.
        """
        if default_route is not None:
            pulumi.set(__self__, "default_route", default_route)
        if microfrontend_group_id is not None:
            pulumi.set(__self__, "microfrontend_group_id", microfrontend_group_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if route_observability_to_this_project is not None:
            pulumi.set(__self__, "route_observability_to_this_project", route_observability_to_this_project)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter(name="defaultRoute")
    def default_route(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The default route for the project. Used for the screenshot of deployments.
        """
        return pulumi.get(self, "default_route")

    @default_route.setter
    def default_route(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_route", value)

    @_builtins.property
    @pulumi.getter(name="microfrontendGroupId")
    def microfrontend_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the microfrontend group.
        """
        return pulumi.get(self, "microfrontend_group_id")

    @microfrontend_group_id.setter
    def microfrontend_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "microfrontend_group_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="routeObservabilityToThisProject")
    def route_observability_to_this_project(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the project is route observability for this project. If dalse, the project will be route observability for all projects to the default project.
        """
        return pulumi.get(self, "route_observability_to_this_project")

    @route_observability_to_this_project.setter
    def route_observability_to_this_project(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "route_observability_to_this_project", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The team ID to add the microfrontend group to. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.type_token("vercel:index/microfrontendGroupMembership:MicrofrontendGroupMembership")
class MicrofrontendGroupMembership(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_route: Optional[pulumi.Input[_builtins.str]] = None,
                 microfrontend_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 route_observability_to_this_project: Optional[pulumi.Input[_builtins.bool]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a Microfrontend Group Membership resource.

        A Microfrontend Group Membership is a definition of a Vercel Project being a part of a Microfrontend Group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vercel as vercel
        import pulumiverse_vercel as vercel

        parent_mfe_project = vercel.get_project(name="my parent project")
        child_mfe_project = vercel.get_project(name="my child project")
        example_mfe_group = vercel.MicrofrontendGroup("example_mfe_group",
            name="my mfe",
            default_app={
                "project_id": parent_mfe_project.id,
            })
        child_mfe_project_mfe_membership = vercel.MicrofrontendGroupMembership("child_mfe_project_mfe_membership",
            project_id=child_mfe_project_vercel_project["id"],
            microfrontend_group_id=example_mfe_group.id)
        ```

        ## Import

        If importing into a personal account, or with a team configured on the provider, simply use the record id.

        - the microfrontend ID can be taken from the microfrontend settings page

        - the project ID can be taken from the project settings page

        ```sh
        $ pulumi import vercel:index/microfrontendGroupMembership:MicrofrontendGroupMembership example mfe_xxxxxxxxxxxxxxxxxxxxxxxxxxxx/pid_xxxxxxxxxxxxxxxxxxxxxxxxxxxx
        ```

        Alternatively, you can import via the team_id and microfrontend_id.

        - team_id can be found in the team `settings` tab in the Vercel UI.

        - the microfrontend ID can be taken from the microfrontend settings page

        - the project ID can be taken from the project settings page

        ```sh
        $ pulumi import vercel:index/microfrontendGroupMembership:MicrofrontendGroupMembership example team_xxxxxxxxxxxxxxxxxxxxxxxx/mfe_xxxxxxxxxxxxxxxxxxxxxxxxxxxx/pid_xxxxxxxxxxxxxxxxxxxxxxxxxxxx
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] default_route: The default route for the project. Used for the screenshot of deployments.
        :param pulumi.Input[_builtins.str] microfrontend_group_id: The ID of the microfrontend group.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project.
        :param pulumi.Input[_builtins.bool] route_observability_to_this_project: Whether the project is route observability for this project. If dalse, the project will be route observability for all projects to the default project.
        :param pulumi.Input[_builtins.str] team_id: The team ID to add the microfrontend group to. Required when configuring a team resource if a default team has not been set in the provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MicrofrontendGroupMembershipArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Microfrontend Group Membership resource.

        A Microfrontend Group Membership is a definition of a Vercel Project being a part of a Microfrontend Group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vercel as vercel
        import pulumiverse_vercel as vercel

        parent_mfe_project = vercel.get_project(name="my parent project")
        child_mfe_project = vercel.get_project(name="my child project")
        example_mfe_group = vercel.MicrofrontendGroup("example_mfe_group",
            name="my mfe",
            default_app={
                "project_id": parent_mfe_project.id,
            })
        child_mfe_project_mfe_membership = vercel.MicrofrontendGroupMembership("child_mfe_project_mfe_membership",
            project_id=child_mfe_project_vercel_project["id"],
            microfrontend_group_id=example_mfe_group.id)
        ```

        ## Import

        If importing into a personal account, or with a team configured on the provider, simply use the record id.

        - the microfrontend ID can be taken from the microfrontend settings page

        - the project ID can be taken from the project settings page

        ```sh
        $ pulumi import vercel:index/microfrontendGroupMembership:MicrofrontendGroupMembership example mfe_xxxxxxxxxxxxxxxxxxxxxxxxxxxx/pid_xxxxxxxxxxxxxxxxxxxxxxxxxxxx
        ```

        Alternatively, you can import via the team_id and microfrontend_id.

        - team_id can be found in the team `settings` tab in the Vercel UI.

        - the microfrontend ID can be taken from the microfrontend settings page

        - the project ID can be taken from the project settings page

        ```sh
        $ pulumi import vercel:index/microfrontendGroupMembership:MicrofrontendGroupMembership example team_xxxxxxxxxxxxxxxxxxxxxxxx/mfe_xxxxxxxxxxxxxxxxxxxxxxxxxxxx/pid_xxxxxxxxxxxxxxxxxxxxxxxxxxxx
        ```

        :param str resource_name: The name of the resource.
        :param MicrofrontendGroupMembershipArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MicrofrontendGroupMembershipArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_route: Optional[pulumi.Input[_builtins.str]] = None,
                 microfrontend_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 route_observability_to_this_project: Optional[pulumi.Input[_builtins.bool]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MicrofrontendGroupMembershipArgs.__new__(MicrofrontendGroupMembershipArgs)

            __props__.__dict__["default_route"] = default_route
            if microfrontend_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'microfrontend_group_id'")
            __props__.__dict__["microfrontend_group_id"] = microfrontend_group_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["route_observability_to_this_project"] = route_observability_to_this_project
            __props__.__dict__["team_id"] = team_id
        super(MicrofrontendGroupMembership, __self__).__init__(
            'vercel:index/microfrontendGroupMembership:MicrofrontendGroupMembership',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            default_route: Optional[pulumi.Input[_builtins.str]] = None,
            microfrontend_group_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            route_observability_to_this_project: Optional[pulumi.Input[_builtins.bool]] = None,
            team_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'MicrofrontendGroupMembership':
        """
        Get an existing MicrofrontendGroupMembership resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] default_route: The default route for the project. Used for the screenshot of deployments.
        :param pulumi.Input[_builtins.str] microfrontend_group_id: The ID of the microfrontend group.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project.
        :param pulumi.Input[_builtins.bool] route_observability_to_this_project: Whether the project is route observability for this project. If dalse, the project will be route observability for all projects to the default project.
        :param pulumi.Input[_builtins.str] team_id: The team ID to add the microfrontend group to. Required when configuring a team resource if a default team has not been set in the provider.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MicrofrontendGroupMembershipState.__new__(_MicrofrontendGroupMembershipState)

        __props__.__dict__["default_route"] = default_route
        __props__.__dict__["microfrontend_group_id"] = microfrontend_group_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["route_observability_to_this_project"] = route_observability_to_this_project
        __props__.__dict__["team_id"] = team_id
        return MicrofrontendGroupMembership(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="defaultRoute")
    def default_route(self) -> pulumi.Output[_builtins.str]:
        """
        The default route for the project. Used for the screenshot of deployments.
        """
        return pulumi.get(self, "default_route")

    @_builtins.property
    @pulumi.getter(name="microfrontendGroupId")
    def microfrontend_group_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the microfrontend group.
        """
        return pulumi.get(self, "microfrontend_group_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="routeObservabilityToThisProject")
    def route_observability_to_this_project(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the project is route observability for this project. If dalse, the project will be route observability for all projects to the default project.
        """
        return pulumi.get(self, "route_observability_to_this_project")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[_builtins.str]:
        """
        The team ID to add the microfrontend group to. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 api_token: Optional[pulumi.Input[_builtins.str]] = None,
                 team: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[_builtins.str] api_token: The Vercel API Token to use. This can also be specified with the `VERCEL_API_TOKEN` shell environment variable. Tokens can be created from your [Vercel settings](https://vercel.com/account/tokens).
        :param pulumi.Input[_builtins.str] team: The default Vercel Team to use when creating resources or reading data sources. This can be provided as either a team slug, or team ID. The slug and ID are both available from the Team Settings page in the Vercel dashboard.
        """
        if api_token is not None:
            pulumi.set(__self__, "api_token", api_token)
        if team is not None:
            pulumi.set(__self__, "team", team)

    @_builtins.property
    @pulumi.getter(name="apiToken")
    def api_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Vercel API Token to use. This can also be specified with the `VERCEL_API_TOKEN` shell environment variable. Tokens can be created from your [Vercel settings](https://vercel.com/account/tokens).
        """
        return pulumi.get(self, "api_token")

    @api_token.setter
    def api_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_token", value)

    @_builtins.property
    @pulumi.getter
    def team(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The default Vercel Team to use when creating resources or reading data sources. This can be provided as either a team slug, or team ID. The slug and ID are both available from the Team Settings page in the Vercel dashboard.
        """
        return pulumi.get(self, "team")

    @team.setter
    def team(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team", value)


@pulumi.type_token("pulumi:providers:vercel")
class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_token: Optional[pulumi.Input[_builtins.str]] = None,
                 team: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The provider type for the vercel package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_token: The Vercel API Token to use. This can also be specified with the `VERCEL_API_TOKEN` shell environment variable. Tokens can be created from your [Vercel settings](https://vercel.com/account/tokens).
        :param pulumi.Input[_builtins.str] team: The default Vercel Team to use when creating resources or reading data sources. This can be provided as either a team slug, or team ID. The slug and ID are both available from the Team Settings page in the Vercel dashboard.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the vercel package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_token: Optional[pulumi.Input[_builtins.str]] = None,
                 team: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["api_token"] = None if api_token is None else pulumi.Output.secret(api_token)
            __props__.__dict__["team"] = team
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["apiToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Provider, __self__).__init__(
            'vercel',
            resource_name,
            __props__,
            opts)

    @_builtins.property
    @pulumi.getter(name="apiToken")
    def api_token(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The Vercel API Token to use. This can also be specified with the `VERCEL_API_TOKEN` shell environment variable. Tokens can be created from your [Vercel settings](https://vercel.com/account/tokens).
        """
        return pulumi.get(self, "api_token")

    @_builtins.property
    @pulumi.getter
    def team(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The default Vercel Team to use when creating resources or reading data sources. This can be provided as either a team slug, or team ID. The slug and ID are both available from the Team Settings page in the Vercel dashboard.
        """
        return pulumi.get(self, "team")

    @pulumi.output_type
    class TerraformConfigResult:
        def __init__(__self__, result=None):
            if result and not isinstance(result, dict):
                raise TypeError("Expected argument 'result' to be a dict")
            pulumi.set(__self__, "result", result)

        @_builtins.property
        @pulumi.getter
        def result(self) -> Mapping[str, Any]:
            return pulumi.get(self, "result")

    def terraform_config(__self__) -> pulumi.Output['Provider.TerraformConfigResult']:
        """
        This function returns a Terraform config object with terraform-namecased keys,to be used with the Terraform Module Provider.
        """
        __args__ = dict()
        __args__['__self__'] = __self__
        return pulumi.runtime.call('pulumi:providers:vercel/terraformConfig', __args__, res=__self__, typ=Provider.TerraformConfigResult)




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectResult',
    'AwaitableGetProjectResult',
    'get_project',
    'get_project_output',
]

@pulumi.output_type
class GetProjectResult:
    """
    A collection of values returned by getProject.
    """
    def __init__(__self__, auto_assign_custom_domains=None, automatically_expose_system_environment_variables=None, build_command=None, build_machine_type=None, customer_success_code_visibility=None, dev_command=None, directory_listing=None, enable_affected_projects_deployments=None, enable_preview_feedback=None, enable_production_feedback=None, environments=None, framework=None, function_failover=None, git_comments=None, git_fork_protection=None, git_lfs=None, git_provider_options=None, git_repository=None, id=None, ignore_command=None, install_command=None, name=None, node_version=None, oidc_token_config=None, on_demand_concurrent_builds=None, options_allowlist=None, output_directory=None, password_protection=None, preview_comments=None, preview_deployment_suffix=None, preview_deployments_disabled=None, prioritise_production_builds=None, protection_bypass_for_automation=None, protection_bypass_for_automation_secret=None, public_source=None, resource_config=None, root_directory=None, serverless_function_region=None, skew_protection=None, team_id=None, trusted_ips=None, vercel_authentication=None):
        if auto_assign_custom_domains and not isinstance(auto_assign_custom_domains, bool):
            raise TypeError("Expected argument 'auto_assign_custom_domains' to be a bool")
        pulumi.set(__self__, "auto_assign_custom_domains", auto_assign_custom_domains)
        if automatically_expose_system_environment_variables and not isinstance(automatically_expose_system_environment_variables, bool):
            raise TypeError("Expected argument 'automatically_expose_system_environment_variables' to be a bool")
        pulumi.set(__self__, "automatically_expose_system_environment_variables", automatically_expose_system_environment_variables)
        if build_command and not isinstance(build_command, str):
            raise TypeError("Expected argument 'build_command' to be a str")
        pulumi.set(__self__, "build_command", build_command)
        if build_machine_type and not isinstance(build_machine_type, str):
            raise TypeError("Expected argument 'build_machine_type' to be a str")
        pulumi.set(__self__, "build_machine_type", build_machine_type)
        if customer_success_code_visibility and not isinstance(customer_success_code_visibility, bool):
            raise TypeError("Expected argument 'customer_success_code_visibility' to be a bool")
        pulumi.set(__self__, "customer_success_code_visibility", customer_success_code_visibility)
        if dev_command and not isinstance(dev_command, str):
            raise TypeError("Expected argument 'dev_command' to be a str")
        pulumi.set(__self__, "dev_command", dev_command)
        if directory_listing and not isinstance(directory_listing, bool):
            raise TypeError("Expected argument 'directory_listing' to be a bool")
        pulumi.set(__self__, "directory_listing", directory_listing)
        if enable_affected_projects_deployments and not isinstance(enable_affected_projects_deployments, bool):
            raise TypeError("Expected argument 'enable_affected_projects_deployments' to be a bool")
        pulumi.set(__self__, "enable_affected_projects_deployments", enable_affected_projects_deployments)
        if enable_preview_feedback and not isinstance(enable_preview_feedback, bool):
            raise TypeError("Expected argument 'enable_preview_feedback' to be a bool")
        pulumi.set(__self__, "enable_preview_feedback", enable_preview_feedback)
        if enable_production_feedback and not isinstance(enable_production_feedback, bool):
            raise TypeError("Expected argument 'enable_production_feedback' to be a bool")
        pulumi.set(__self__, "enable_production_feedback", enable_production_feedback)
        if environments and not isinstance(environments, list):
            raise TypeError("Expected argument 'environments' to be a list")
        pulumi.set(__self__, "environments", environments)
        if framework and not isinstance(framework, str):
            raise TypeError("Expected argument 'framework' to be a str")
        pulumi.set(__self__, "framework", framework)
        if function_failover and not isinstance(function_failover, bool):
            raise TypeError("Expected argument 'function_failover' to be a bool")
        pulumi.set(__self__, "function_failover", function_failover)
        if git_comments and not isinstance(git_comments, dict):
            raise TypeError("Expected argument 'git_comments' to be a dict")
        pulumi.set(__self__, "git_comments", git_comments)
        if git_fork_protection and not isinstance(git_fork_protection, bool):
            raise TypeError("Expected argument 'git_fork_protection' to be a bool")
        pulumi.set(__self__, "git_fork_protection", git_fork_protection)
        if git_lfs and not isinstance(git_lfs, bool):
            raise TypeError("Expected argument 'git_lfs' to be a bool")
        pulumi.set(__self__, "git_lfs", git_lfs)
        if git_provider_options and not isinstance(git_provider_options, dict):
            raise TypeError("Expected argument 'git_provider_options' to be a dict")
        pulumi.set(__self__, "git_provider_options", git_provider_options)
        if git_repository and not isinstance(git_repository, dict):
            raise TypeError("Expected argument 'git_repository' to be a dict")
        pulumi.set(__self__, "git_repository", git_repository)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ignore_command and not isinstance(ignore_command, str):
            raise TypeError("Expected argument 'ignore_command' to be a str")
        pulumi.set(__self__, "ignore_command", ignore_command)
        if install_command and not isinstance(install_command, str):
            raise TypeError("Expected argument 'install_command' to be a str")
        pulumi.set(__self__, "install_command", install_command)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if node_version and not isinstance(node_version, str):
            raise TypeError("Expected argument 'node_version' to be a str")
        pulumi.set(__self__, "node_version", node_version)
        if oidc_token_config and not isinstance(oidc_token_config, dict):
            raise TypeError("Expected argument 'oidc_token_config' to be a dict")
        pulumi.set(__self__, "oidc_token_config", oidc_token_config)
        if on_demand_concurrent_builds and not isinstance(on_demand_concurrent_builds, bool):
            raise TypeError("Expected argument 'on_demand_concurrent_builds' to be a bool")
        pulumi.set(__self__, "on_demand_concurrent_builds", on_demand_concurrent_builds)
        if options_allowlist and not isinstance(options_allowlist, dict):
            raise TypeError("Expected argument 'options_allowlist' to be a dict")
        pulumi.set(__self__, "options_allowlist", options_allowlist)
        if output_directory and not isinstance(output_directory, str):
            raise TypeError("Expected argument 'output_directory' to be a str")
        pulumi.set(__self__, "output_directory", output_directory)
        if password_protection and not isinstance(password_protection, dict):
            raise TypeError("Expected argument 'password_protection' to be a dict")
        pulumi.set(__self__, "password_protection", password_protection)
        if preview_comments and not isinstance(preview_comments, bool):
            raise TypeError("Expected argument 'preview_comments' to be a bool")
        pulumi.set(__self__, "preview_comments", preview_comments)
        if preview_deployment_suffix and not isinstance(preview_deployment_suffix, str):
            raise TypeError("Expected argument 'preview_deployment_suffix' to be a str")
        pulumi.set(__self__, "preview_deployment_suffix", preview_deployment_suffix)
        if preview_deployments_disabled and not isinstance(preview_deployments_disabled, bool):
            raise TypeError("Expected argument 'preview_deployments_disabled' to be a bool")
        pulumi.set(__self__, "preview_deployments_disabled", preview_deployments_disabled)
        if prioritise_production_builds and not isinstance(prioritise_production_builds, bool):
            raise TypeError("Expected argument 'prioritise_production_builds' to be a bool")
        pulumi.set(__self__, "prioritise_production_builds", prioritise_production_builds)
        if protection_bypass_for_automation and not isinstance(protection_bypass_for_automation, bool):
            raise TypeError("Expected argument 'protection_bypass_for_automation' to be a bool")
        pulumi.set(__self__, "protection_bypass_for_automation", protection_bypass_for_automation)
        if protection_bypass_for_automation_secret and not isinstance(protection_bypass_for_automation_secret, str):
            raise TypeError("Expected argument 'protection_bypass_for_automation_secret' to be a str")
        pulumi.set(__self__, "protection_bypass_for_automation_secret", protection_bypass_for_automation_secret)
        if public_source and not isinstance(public_source, bool):
            raise TypeError("Expected argument 'public_source' to be a bool")
        pulumi.set(__self__, "public_source", public_source)
        if resource_config and not isinstance(resource_config, dict):
            raise TypeError("Expected argument 'resource_config' to be a dict")
        pulumi.set(__self__, "resource_config", resource_config)
        if root_directory and not isinstance(root_directory, str):
            raise TypeError("Expected argument 'root_directory' to be a str")
        pulumi.set(__self__, "root_directory", root_directory)
        if serverless_function_region and not isinstance(serverless_function_region, str):
            raise TypeError("Expected argument 'serverless_function_region' to be a str")
        pulumi.set(__self__, "serverless_function_region", serverless_function_region)
        if skew_protection and not isinstance(skew_protection, str):
            raise TypeError("Expected argument 'skew_protection' to be a str")
        pulumi.set(__self__, "skew_protection", skew_protection)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)
        if trusted_ips and not isinstance(trusted_ips, dict):
            raise TypeError("Expected argument 'trusted_ips' to be a dict")
        pulumi.set(__self__, "trusted_ips", trusted_ips)
        if vercel_authentication and not isinstance(vercel_authentication, dict):
            raise TypeError("Expected argument 'vercel_authentication' to be a dict")
        pulumi.set(__self__, "vercel_authentication", vercel_authentication)

    @_builtins.property
    @pulumi.getter(name="autoAssignCustomDomains")
    def auto_assign_custom_domains(self) -> _builtins.bool:
        """
        Automatically assign custom production domains after each Production deployment via merge to the production branch or Vercel CLI deploy with --prod. Defaults to `true`
        """
        return pulumi.get(self, "auto_assign_custom_domains")

    @_builtins.property
    @pulumi.getter(name="automaticallyExposeSystemEnvironmentVariables")
    def automatically_expose_system_environment_variables(self) -> _builtins.bool:
        """
        Vercel provides a set of Environment Variables that are automatically populated by the System, such as the URL of the Deployment or the name of the Git branch deployed. To expose them to your Deployments, enable this field
        """
        return pulumi.get(self, "automatically_expose_system_environment_variables")

    @_builtins.property
    @pulumi.getter(name="buildCommand")
    def build_command(self) -> _builtins.str:
        """
        The build command for this project. If omitted, this value will be automatically detected.
        """
        return pulumi.get(self, "build_command")

    @_builtins.property
    @pulumi.getter(name="buildMachineType")
    def build_machine_type(self) -> _builtins.str:
        """
        The build machine type to use for this project.
        """
        return pulumi.get(self, "build_machine_type")

    @_builtins.property
    @pulumi.getter(name="customerSuccessCodeVisibility")
    def customer_success_code_visibility(self) -> _builtins.bool:
        """
        Allows Vercel Customer Support to inspect all Deployments' source code in this project to assist with debugging.
        """
        return pulumi.get(self, "customer_success_code_visibility")

    @_builtins.property
    @pulumi.getter(name="devCommand")
    def dev_command(self) -> _builtins.str:
        """
        The dev command for this project. If omitted, this value will be automatically detected.
        """
        return pulumi.get(self, "dev_command")

    @_builtins.property
    @pulumi.getter(name="directoryListing")
    def directory_listing(self) -> _builtins.bool:
        """
        If no index file is present within a directory, the directory contents will be displayed.
        """
        return pulumi.get(self, "directory_listing")

    @_builtins.property
    @pulumi.getter(name="enableAffectedProjectsDeployments")
    def enable_affected_projects_deployments(self) -> _builtins.bool:
        """
        When enabled, Vercel will automatically deploy all projects that are affected by a change to this project.
        """
        return pulumi.get(self, "enable_affected_projects_deployments")

    @_builtins.property
    @pulumi.getter(name="enablePreviewFeedback")
    def enable_preview_feedback(self) -> _builtins.bool:
        """
        Whether the Vercel Toolbar is enabled on your preview deployments. If unspecified, defaults to team setting.
        """
        return pulumi.get(self, "enable_preview_feedback")

    @_builtins.property
    @pulumi.getter(name="enableProductionFeedback")
    def enable_production_feedback(self) -> _builtins.bool:
        """
        Whether the Vercel Toolbar is enabled on your production deployments. If unspecified, defaults to team setting.
        """
        return pulumi.get(self, "enable_production_feedback")

    @_builtins.property
    @pulumi.getter
    def environments(self) -> Sequence['outputs.GetProjectEnvironmentResult']:
        """
        A list of environment variables that should be configured for the project.
        """
        return pulumi.get(self, "environments")

    @_builtins.property
    @pulumi.getter
    def framework(self) -> _builtins.str:
        """
        The framework that is being used for this project. If omitted, no framework is selected.
        """
        return pulumi.get(self, "framework")

    @_builtins.property
    @pulumi.getter(name="functionFailover")
    def function_failover(self) -> _builtins.bool:
        """
        Automatically failover Serverless Functions to the nearest region. You can customize regions through vercel.json. A new Deployment is required for your changes to take effect.
        """
        return pulumi.get(self, "function_failover")

    @_builtins.property
    @pulumi.getter(name="gitComments")
    def git_comments(self) -> 'outputs.GetProjectGitCommentsResult':
        """
        Configuration for Git Comments.
        """
        return pulumi.get(self, "git_comments")

    @_builtins.property
    @pulumi.getter(name="gitForkProtection")
    def git_fork_protection(self) -> _builtins.bool:
        """
        Ensures that pull requests targeting your Git repository must be authorized by a member of your Team before deploying if your Project has Environment Variables or if the pull request includes a change to vercel.json.
        """
        return pulumi.get(self, "git_fork_protection")

    @_builtins.property
    @pulumi.getter(name="gitLfs")
    def git_lfs(self) -> _builtins.bool:
        """
        Enables Git LFS support. Git LFS replaces large files such as audio samples, videos, datasets, and graphics with text pointers inside Git, while storing the file contents on a remote server like GitHub.com or GitHub Enterprise.
        """
        return pulumi.get(self, "git_lfs")

    @_builtins.property
    @pulumi.getter(name="gitProviderOptions")
    def git_provider_options(self) -> 'outputs.GetProjectGitProviderOptionsResult':
        """
        Git provider options.
        """
        return pulumi.get(self, "git_provider_options")

    @_builtins.property
    @pulumi.getter(name="gitRepository")
    def git_repository(self) -> 'outputs.GetProjectGitRepositoryResult':
        """
        The Git Repository that will be connected to the project. When this is defined, any pushes to the specified connected Git Repository will be automatically deployed. This requires the corresponding Vercel for [Github](https://vercel.com/docs/concepts/git/vercel-for-github), [Gitlab](https://vercel.com/docs/concepts/git/vercel-for-gitlab) or [Bitbucket](https://vercel.com/docs/concepts/git/vercel-for-bitbucket) plugins to be installed.
        """
        return pulumi.get(self, "git_repository")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="ignoreCommand")
    def ignore_command(self) -> _builtins.str:
        """
        When a commit is pushed to the Git repository that is connected with your Project, its SHA will determine if a new Build has to be issued. If the SHA was deployed before, no new Build will be issued. You can customize this behavior with a command that exits with code 1 (new Build needed) or code 0.
        """
        return pulumi.get(self, "ignore_command")

    @_builtins.property
    @pulumi.getter(name="installCommand")
    def install_command(self) -> _builtins.str:
        """
        The install command for this project. If omitted, this value will be automatically detected.
        """
        return pulumi.get(self, "install_command")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the project.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodeVersion")
    def node_version(self) -> _builtins.str:
        """
        The version of Node.js that is used in the Build Step and for Serverless Functions.
        """
        return pulumi.get(self, "node_version")

    @_builtins.property
    @pulumi.getter(name="oidcTokenConfig")
    def oidc_token_config(self) -> 'outputs.GetProjectOidcTokenConfigResult':
        """
        Configuration for OpenID Connect (OIDC) tokens.
        """
        return pulumi.get(self, "oidc_token_config")

    @_builtins.property
    @pulumi.getter(name="onDemandConcurrentBuilds")
    def on_demand_concurrent_builds(self) -> _builtins.bool:
        """
        Instantly scale build capacity to skip the queue, even if all build slots are in use. You can also choose a larger build machine; charges apply per minute if it exceeds your team's default.
        """
        return pulumi.get(self, "on_demand_concurrent_builds")

    @_builtins.property
    @pulumi.getter(name="optionsAllowlist")
    def options_allowlist(self) -> 'outputs.GetProjectOptionsAllowlistResult':
        """
        Disable Deployment Protection for CORS preflight `OPTIONS` requests for a list of paths.
        """
        return pulumi.get(self, "options_allowlist")

    @_builtins.property
    @pulumi.getter(name="outputDirectory")
    def output_directory(self) -> _builtins.str:
        """
        The output directory of the project. When null is used this value will be automatically detected.
        """
        return pulumi.get(self, "output_directory")

    @_builtins.property
    @pulumi.getter(name="passwordProtection")
    def password_protection(self) -> 'outputs.GetProjectPasswordProtectionResult':
        """
        Ensures visitors of your Preview Deployments must enter a password in order to gain access.
        """
        return pulumi.get(self, "password_protection")

    @_builtins.property
    @pulumi.getter(name="previewComments")
    @_utilities.deprecated("""Use `enable_preview_feedback` instead. This attribute will be removed in a future version.""")
    def preview_comments(self) -> _builtins.bool:
        """
        Whether comments are enabled on your Preview Deployments.
        """
        return pulumi.get(self, "preview_comments")

    @_builtins.property
    @pulumi.getter(name="previewDeploymentSuffix")
    def preview_deployment_suffix(self) -> _builtins.str:
        """
        The preview deployment suffix to apply to preview deployment URLs for this project.
        """
        return pulumi.get(self, "preview_deployment_suffix")

    @_builtins.property
    @pulumi.getter(name="previewDeploymentsDisabled")
    def preview_deployments_disabled(self) -> _builtins.bool:
        """
        Whether Preview Deployments are disabled for this project.
        """
        return pulumi.get(self, "preview_deployments_disabled")

    @_builtins.property
    @pulumi.getter(name="prioritiseProductionBuilds")
    def prioritise_production_builds(self) -> _builtins.bool:
        """
        If enabled, builds for the Production environment will be prioritized over Preview environments.
        """
        return pulumi.get(self, "prioritise_production_builds")

    @_builtins.property
    @pulumi.getter(name="protectionBypassForAutomation")
    def protection_bypass_for_automation(self) -> _builtins.bool:
        """
        Allows automation services to bypass Deployment Protection on this project when using an HTTP header named `x-vercel-protection-bypass` with the value from `protection_bypass_for_automation_secret`.
        """
        return pulumi.get(self, "protection_bypass_for_automation")

    @_builtins.property
    @pulumi.getter(name="protectionBypassForAutomationSecret")
    def protection_bypass_for_automation_secret(self) -> _builtins.str:
        """
        If `protection_bypass_for_automation` is enabled, optionally set this value to specify a 32 character secret, otherwise a secret will be generated.
        """
        return pulumi.get(self, "protection_bypass_for_automation_secret")

    @_builtins.property
    @pulumi.getter(name="publicSource")
    def public_source(self) -> _builtins.bool:
        """
        Specifies whether the source code and logs of the deployments for this project should be public or not.
        """
        return pulumi.get(self, "public_source")

    @_builtins.property
    @pulumi.getter(name="resourceConfig")
    def resource_config(self) -> 'outputs.GetProjectResourceConfigResult':
        """
        Resource Configuration for the project.
        """
        return pulumi.get(self, "resource_config")

    @_builtins.property
    @pulumi.getter(name="rootDirectory")
    def root_directory(self) -> _builtins.str:
        """
        The name of a directory or relative path to the source code of your project. When null is used it will default to the project root.
        """
        return pulumi.get(self, "root_directory")

    @_builtins.property
    @pulumi.getter(name="serverlessFunctionRegion")
    def serverless_function_region(self) -> _builtins.str:
        """
        The region on Vercel's network to which your Serverless Functions are deployed. It should be close to any data source your Serverless Function might depend on. A new Deployment is required for your changes to take effect. Please see [Vercel's documentation](https://vercel.com/docs/concepts/edge-network/regions) for a full list of regions.
        """
        return pulumi.get(self, "serverless_function_region")

    @_builtins.property
    @pulumi.getter(name="skewProtection")
    def skew_protection(self) -> _builtins.str:
        """
        Ensures that outdated clients always fetch the correct version for a given deployment. This value defines how long Vercel keeps Skew Protection active.
        """
        return pulumi.get(self, "skew_protection")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The team ID the project exists beneath. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @_builtins.property
    @pulumi.getter(name="trustedIps")
    def trusted_ips(self) -> 'outputs.GetProjectTrustedIpsResult':
        """
        Ensures only visitors from an allowed IP address can access your deployment.
        """
        return pulumi.get(self, "trusted_ips")

    @_builtins.property
    @pulumi.getter(name="vercelAuthentication")
    def vercel_authentication(self) -> 'outputs.GetProjectVercelAuthenticationResult':
        """
        Ensures visitors to your Preview Deployments are logged into Vercel and have a minimum of Viewer access on your team.
        """
        return pulumi.get(self, "vercel_authentication")


class AwaitableGetProjectResult(GetProjectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectResult(
            auto_assign_custom_domains=self.auto_assign_custom_domains,
            automatically_expose_system_environment_variables=self.automatically_expose_system_environment_variables,
            build_command=self.build_command,
            build_machine_type=self.build_machine_type,
            customer_success_code_visibility=self.customer_success_code_visibility,
            dev_command=self.dev_command,
            directory_listing=self.directory_listing,
            enable_affected_projects_deployments=self.enable_affected_projects_deployments,
            enable_preview_feedback=self.enable_preview_feedback,
            enable_production_feedback=self.enable_production_feedback,
            environments=self.environments,
            framework=self.framework,
            function_failover=self.function_failover,
            git_comments=self.git_comments,
            git_fork_protection=self.git_fork_protection,
            git_lfs=self.git_lfs,
            git_provider_options=self.git_provider_options,
            git_repository=self.git_repository,
            id=self.id,
            ignore_command=self.ignore_command,
            install_command=self.install_command,
            name=self.name,
            node_version=self.node_version,
            oidc_token_config=self.oidc_token_config,
            on_demand_concurrent_builds=self.on_demand_concurrent_builds,
            options_allowlist=self.options_allowlist,
            output_directory=self.output_directory,
            password_protection=self.password_protection,
            preview_comments=self.preview_comments,
            preview_deployment_suffix=self.preview_deployment_suffix,
            preview_deployments_disabled=self.preview_deployments_disabled,
            prioritise_production_builds=self.prioritise_production_builds,
            protection_bypass_for_automation=self.protection_bypass_for_automation,
            protection_bypass_for_automation_secret=self.protection_bypass_for_automation_secret,
            public_source=self.public_source,
            resource_config=self.resource_config,
            root_directory=self.root_directory,
            serverless_function_region=self.serverless_function_region,
            skew_protection=self.skew_protection,
            team_id=self.team_id,
            trusted_ips=self.trusted_ips,
            vercel_authentication=self.vercel_authentication)


def get_project(build_machine_type: Optional[_builtins.str] = None,
                name: Optional[_builtins.str] = None,
                on_demand_concurrent_builds: Optional[_builtins.bool] = None,
                team_id: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectResult:
    """
    Provides information about an existing project within Vercel.

    A Project groups deployments and custom domains. To deploy on Vercel, you need a Project.

    For more detailed information, please see the [Vercel documentation](https://vercel.com/docs/concepts/projects/overview).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_project(name="my-existing-project")
    ```


    :param _builtins.str build_machine_type: The build machine type to use for this project.
    :param _builtins.str name: The name of the project.
    :param _builtins.bool on_demand_concurrent_builds: Instantly scale build capacity to skip the queue, even if all build slots are in use. You can also choose a larger build machine; charges apply per minute if it exceeds your team's default.
    :param _builtins.str team_id: The team ID the project exists beneath. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['buildMachineType'] = build_machine_type
    __args__['name'] = name
    __args__['onDemandConcurrentBuilds'] = on_demand_concurrent_builds
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getProject:getProject', __args__, opts=opts, typ=GetProjectResult).value

    return AwaitableGetProjectResult(
        auto_assign_custom_domains=pulumi.get(__ret__, 'auto_assign_custom_domains'),
        automatically_expose_system_environment_variables=pulumi.get(__ret__, 'automatically_expose_system_environment_variables'),
        build_command=pulumi.get(__ret__, 'build_command'),
        build_machine_type=pulumi.get(__ret__, 'build_machine_type'),
        customer_success_code_visibility=pulumi.get(__ret__, 'customer_success_code_visibility'),
        dev_command=pulumi.get(__ret__, 'dev_command'),
        directory_listing=pulumi.get(__ret__, 'directory_listing'),
        enable_affected_projects_deployments=pulumi.get(__ret__, 'enable_affected_projects_deployments'),
        enable_preview_feedback=pulumi.get(__ret__, 'enable_preview_feedback'),
        enable_production_feedback=pulumi.get(__ret__, 'enable_production_feedback'),
        environments=pulumi.get(__ret__, 'environments'),
        framework=pulumi.get(__ret__, 'framework'),
        function_failover=pulumi.get(__ret__, 'function_failover'),
        git_comments=pulumi.get(__ret__, 'git_comments'),
        git_fork_protection=pulumi.get(__ret__, 'git_fork_protection'),
        git_lfs=pulumi.get(__ret__, 'git_lfs'),
        git_provider_options=pulumi.get(__ret__, 'git_provider_options'),
        git_repository=pulumi.get(__ret__, 'git_repository'),
        id=pulumi.get(__ret__, 'id'),
        ignore_command=pulumi.get(__ret__, 'ignore_command'),
        install_command=pulumi.get(__ret__, 'install_command'),
        name=pulumi.get(__ret__, 'name'),
        node_version=pulumi.get(__ret__, 'node_version'),
        oidc_token_config=pulumi.get(__ret__, 'oidc_token_config'),
        on_demand_concurrent_builds=pulumi.get(__ret__, 'on_demand_concurrent_builds'),
        options_allowlist=pulumi.get(__ret__, 'options_allowlist'),
        output_directory=pulumi.get(__ret__, 'output_directory'),
        password_protection=pulumi.get(__ret__, 'password_protection'),
        preview_comments=pulumi.get(__ret__, 'preview_comments'),
        preview_deployment_suffix=pulumi.get(__ret__, 'preview_deployment_suffix'),
        preview_deployments_disabled=pulumi.get(__ret__, 'preview_deployments_disabled'),
        prioritise_production_builds=pulumi.get(__ret__, 'prioritise_production_builds'),
        protection_bypass_for_automation=pulumi.get(__ret__, 'protection_bypass_for_automation'),
        protection_bypass_for_automation_secret=pulumi.get(__ret__, 'protection_bypass_for_automation_secret'),
        public_source=pulumi.get(__ret__, 'public_source'),
        resource_config=pulumi.get(__ret__, 'resource_config'),
        root_directory=pulumi.get(__ret__, 'root_directory'),
        serverless_function_region=pulumi.get(__ret__, 'serverless_function_region'),
        skew_protection=pulumi.get(__ret__, 'skew_protection'),
        team_id=pulumi.get(__ret__, 'team_id'),
        trusted_ips=pulumi.get(__ret__, 'trusted_ips'),
        vercel_authentication=pulumi.get(__ret__, 'vercel_authentication'))
def get_project_output(build_machine_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       name: Optional[pulumi.Input[_builtins.str]] = None,
                       on_demand_concurrent_builds: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                       team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectResult]:
    """
    Provides information about an existing project within Vercel.

    A Project groups deployments and custom domains. To deploy on Vercel, you need a Project.

    For more detailed information, please see the [Vercel documentation](https://vercel.com/docs/concepts/projects/overview).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_project(name="my-existing-project")
    ```


    :param _builtins.str build_machine_type: The build machine type to use for this project.
    :param _builtins.str name: The name of the project.
    :param _builtins.bool on_demand_concurrent_builds: Instantly scale build capacity to skip the queue, even if all build slots are in use. You can also choose a larger build machine; charges apply per minute if it exceeds your team's default.
    :param _builtins.str team_id: The team ID the project exists beneath. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['buildMachineType'] = build_machine_type
    __args__['name'] = name
    __args__['onDemandConcurrentBuilds'] = on_demand_concurrent_builds
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getProject:getProject', __args__, opts=opts, typ=GetProjectResult)
    return __ret__.apply(lambda __response__: GetProjectResult(
        auto_assign_custom_domains=pulumi.get(__response__, 'auto_assign_custom_domains'),
        automatically_expose_system_environment_variables=pulumi.get(__response__, 'automatically_expose_system_environment_variables'),
        build_command=pulumi.get(__response__, 'build_command'),
        build_machine_type=pulumi.get(__response__, 'build_machine_type'),
        customer_success_code_visibility=pulumi.get(__response__, 'customer_success_code_visibility'),
        dev_command=pulumi.get(__response__, 'dev_command'),
        directory_listing=pulumi.get(__response__, 'directory_listing'),
        enable_affected_projects_deployments=pulumi.get(__response__, 'enable_affected_projects_deployments'),
        enable_preview_feedback=pulumi.get(__response__, 'enable_preview_feedback'),
        enable_production_feedback=pulumi.get(__response__, 'enable_production_feedback'),
        environments=pulumi.get(__response__, 'environments'),
        framework=pulumi.get(__response__, 'framework'),
        function_failover=pulumi.get(__response__, 'function_failover'),
        git_comments=pulumi.get(__response__, 'git_comments'),
        git_fork_protection=pulumi.get(__response__, 'git_fork_protection'),
        git_lfs=pulumi.get(__response__, 'git_lfs'),
        git_provider_options=pulumi.get(__response__, 'git_provider_options'),
        git_repository=pulumi.get(__response__, 'git_repository'),
        id=pulumi.get(__response__, 'id'),
        ignore_command=pulumi.get(__response__, 'ignore_command'),
        install_command=pulumi.get(__response__, 'install_command'),
        name=pulumi.get(__response__, 'name'),
        node_version=pulumi.get(__response__, 'node_version'),
        oidc_token_config=pulumi.get(__response__, 'oidc_token_config'),
        on_demand_concurrent_builds=pulumi.get(__response__, 'on_demand_concurrent_builds'),
        options_allowlist=pulumi.get(__response__, 'options_allowlist'),
        output_directory=pulumi.get(__response__, 'output_directory'),
        password_protection=pulumi.get(__response__, 'password_protection'),
        preview_comments=pulumi.get(__response__, 'preview_comments'),
        preview_deployment_suffix=pulumi.get(__response__, 'preview_deployment_suffix'),
        preview_deployments_disabled=pulumi.get(__response__, 'preview_deployments_disabled'),
        prioritise_production_builds=pulumi.get(__response__, 'prioritise_production_builds'),
        protection_bypass_for_automation=pulumi.get(__response__, 'protection_bypass_for_automation'),
        protection_bypass_for_automation_secret=pulumi.get(__response__, 'protection_bypass_for_automation_secret'),
        public_source=pulumi.get(__response__, 'public_source'),
        resource_config=pulumi.get(__response__, 'resource_config'),
        root_directory=pulumi.get(__response__, 'root_directory'),
        serverless_function_region=pulumi.get(__response__, 'serverless_function_region'),
        skew_protection=pulumi.get(__response__, 'skew_protection'),
        team_id=pulumi.get(__response__, 'team_id'),
        trusted_ips=pulumi.get(__response__, 'trusted_ips'),
        vercel_authentication=pulumi.get(__response__, 'vercel_authentication')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetProjectDirectoryResult',
    'AwaitableGetProjectDirectoryResult',
    'get_project_directory',
    'get_project_directory_output',
]

@pulumi.output_type
class GetProjectDirectoryResult:
    """
    A collection of values returned by getProjectDirectory.
    """
    def __init__(__self__, files=None, id=None, path=None):
        if files and not isinstance(files, dict):
            raise TypeError("Expected argument 'files' to be a dict")
        pulumi.set(__self__, "files", files)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)

    @_builtins.property
    @pulumi.getter
    def files(self) -> Mapping[str, _builtins.str]:
        """
        A map of filename to metadata about the file. The metadata contains the file size and hash, and allows a deployment to be created if the file changes.
        """
        return pulumi.get(self, "files")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def path(self) -> _builtins.str:
        return pulumi.get(self, "path")


class AwaitableGetProjectDirectoryResult(GetProjectDirectoryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectDirectoryResult(
            files=self.files,
            id=self.id,
            path=self.path)


def get_project_directory(path: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectDirectoryResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['path'] = path
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getProjectDirectory:getProjectDirectory', __args__, opts=opts, typ=GetProjectDirectoryResult).value

    return AwaitableGetProjectDirectoryResult(
        files=pulumi.get(__ret__, 'files'),
        id=pulumi.get(__ret__, 'id'),
        path=pulumi.get(__ret__, 'path'))
def get_project_directory_output(path: Optional[pulumi.Input[_builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectDirectoryResult]:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['path'] = path
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getProjectDirectory:getProjectDirectory', __args__, opts=opts, typ=GetProjectDirectoryResult)
    return __ret__.apply(lambda __response__: GetProjectDirectoryResult(
        files=pulumi.get(__response__, 'files'),
        id=pulumi.get(__response__, 'id'),
        path=pulumi.get(__response__, 'path')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProjectRollingReleaseArgs', 'ProjectRollingRelease']

@pulumi.input_type
class ProjectRollingReleaseArgs:
    def __init__(__self__, *,
                 advancement_type: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 stages: pulumi.Input[Sequence[pulumi.Input['ProjectRollingReleaseStageArgs']]],
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ProjectRollingRelease resource.
        :param pulumi.Input[_builtins.str] advancement_type: The type of advancement for the rolling release. Must be either 'automatic' or 'manual-approval'.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectRollingReleaseStageArgs']]] stages: The stages for the rolling release configuration. The last stage must have target_percentage = 100.
        :param pulumi.Input[_builtins.str] team_id: The ID of the Vercel team.
        """
        pulumi.set(__self__, "advancement_type", advancement_type)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "stages", stages)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter(name="advancementType")
    def advancement_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of advancement for the rolling release. Must be either 'automatic' or 'manual-approval'.
        """
        return pulumi.get(self, "advancement_type")

    @advancement_type.setter
    def advancement_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "advancement_type", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def stages(self) -> pulumi.Input[Sequence[pulumi.Input['ProjectRollingReleaseStageArgs']]]:
        """
        The stages for the rolling release configuration. The last stage must have target_percentage = 100.
        """
        return pulumi.get(self, "stages")

    @stages.setter
    def stages(self, value: pulumi.Input[Sequence[pulumi.Input['ProjectRollingReleaseStageArgs']]]):
        pulumi.set(self, "stages", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Vercel team.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.input_type
class _ProjectRollingReleaseState:
    def __init__(__self__, *,
                 advancement_type: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 stages: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectRollingReleaseStageArgs']]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectRollingRelease resources.
        :param pulumi.Input[_builtins.str] advancement_type: The type of advancement for the rolling release. Must be either 'automatic' or 'manual-approval'.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectRollingReleaseStageArgs']]] stages: The stages for the rolling release configuration. The last stage must have target_percentage = 100.
        :param pulumi.Input[_builtins.str] team_id: The ID of the Vercel team.
        """
        if advancement_type is not None:
            pulumi.set(__self__, "advancement_type", advancement_type)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if stages is not None:
            pulumi.set(__self__, "stages", stages)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter(name="advancementType")
    def advancement_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of advancement for the rolling release. Must be either 'automatic' or 'manual-approval'.
        """
        return pulumi.get(self, "advancement_type")

    @advancement_type.setter
    def advancement_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "advancement_type", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def stages(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectRollingReleaseStageArgs']]]]:
        """
        The stages for the rolling release configuration. The last stage must have target_percentage = 100.
        """
        return pulumi.get(self, "stages")

    @stages.setter
    def stages(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectRollingReleaseStageArgs']]]]):
        pulumi.set(self, "stages", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Vercel team.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.type_token("vercel:index/projectRollingRelease:ProjectRollingRelease")
class ProjectRollingRelease(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 advancement_type: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 stages: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectRollingReleaseStageArgs', 'ProjectRollingReleaseStageArgsDict']]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for a Vercel project rolling release configuration.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_vercel as vercel

        example = vercel.Project("example",
            name="example-project",
            skew_protection="12 hours")
        example_project_rolling_release = vercel.ProjectRollingRelease("example",
            project_id=example.id,
            advancement_type="manual-approval",
            stages=[
                {
                    "target_percentage": 20,
                },
                {
                    "target_percentage": 50,
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] advancement_type: The type of advancement for the rolling release. Must be either 'automatic' or 'manual-approval'.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProjectRollingReleaseStageArgs', 'ProjectRollingReleaseStageArgsDict']]]] stages: The stages for the rolling release configuration. The last stage must have target_percentage = 100.
        :param pulumi.Input[_builtins.str] team_id: The ID of the Vercel team.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectRollingReleaseArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for a Vercel project rolling release configuration.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_vercel as vercel

        example = vercel.Project("example",
            name="example-project",
            skew_protection="12 hours")
        example_project_rolling_release = vercel.ProjectRollingRelease("example",
            project_id=example.id,
            advancement_type="manual-approval",
            stages=[
                {
                    "target_percentage": 20,
                },
                {
                    "target_percentage": 50,
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param ProjectRollingReleaseArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectRollingReleaseArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 advancement_type: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 stages: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectRollingReleaseStageArgs', 'ProjectRollingReleaseStageArgsDict']]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectRollingReleaseArgs.__new__(ProjectRollingReleaseArgs)

            if advancement_type is None and not opts.urn:
                raise TypeError("Missing required property 'advancement_type'")
            __props__.__dict__["advancement_type"] = advancement_type
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            if stages is None and not opts.urn:
                raise TypeError("Missing required property 'stages'")
            __props__.__dict__["stages"] = stages
            __props__.__dict__["team_id"] = team_id
        super(ProjectRollingRelease, __self__).__init__(
            'vercel:index/projectRollingRelease:ProjectRollingRelease',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            advancement_type: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            stages: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectRollingReleaseStageArgs', 'ProjectRollingReleaseStageArgsDict']]]]] = None,
            team_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProjectRollingRelease':
        """
        Get an existing ProjectRollingRelease resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] advancement_type: The type of advancement for the rolling release. Must be either 'automatic' or 'manual-approval'.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProjectRollingReleaseStageArgs', 'ProjectRollingReleaseStageArgsDict']]]] stages: The stages for the rolling release configuration. The last stage must have target_percentage = 100.
        :param pulumi.Input[_builtins.str] team_id: The ID of the Vercel team.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectRollingReleaseState.__new__(_ProjectRollingReleaseState)

        __props__.__dict__["advancement_type"] = advancement_type
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["stages"] = stages
        __props__.__dict__["team_id"] = team_id
        return ProjectRollingRelease(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="advancementType")
    def advancement_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of advancement for the rolling release. Must be either 'automatic' or 'manual-approval'.
        """
        return pulumi.get(self, "advancement_type")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def stages(self) -> pulumi.Output[Sequence['outputs.ProjectRollingReleaseStage']]:
        """
        The stages for the rolling release configuration. The last stage must have target_percentage = 100.
        """
        return pulumi.get(self, "stages")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Vercel team.
        """
        return pulumi.get(self, "team_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectRollingReleaseResult',
    'AwaitableGetProjectRollingReleaseResult',
    'get_project_rolling_release',
    'get_project_rolling_release_output',
]

@pulumi.output_type
class GetProjectRollingReleaseResult:
    """
    A collection of values returned by getProjectRollingRelease.
    """
    def __init__(__self__, advancement_type=None, id=None, project_id=None, stages=None, team_id=None):
        if advancement_type and not isinstance(advancement_type, str):
            raise TypeError("Expected argument 'advancement_type' to be a str")
        pulumi.set(__self__, "advancement_type", advancement_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if stages and not isinstance(stages, list):
            raise TypeError("Expected argument 'stages' to be a list")
        pulumi.set(__self__, "stages", stages)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter(name="advancementType")
    def advancement_type(self) -> _builtins.str:
        """
        The type of advancement for the rolling release. Either 'automatic' or 'manual-approval'.
        """
        return pulumi.get(self, "advancement_type")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def stages(self) -> Sequence['outputs.GetProjectRollingReleaseStageResult']:
        """
        The stages for the rolling release configuration.
        """
        return pulumi.get(self, "stages")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The ID of the Vercel team.
        """
        return pulumi.get(self, "team_id")


class AwaitableGetProjectRollingReleaseResult(GetProjectRollingReleaseResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectRollingReleaseResult(
            advancement_type=self.advancement_type,
            id=self.id,
            project_id=self.project_id,
            stages=self.stages,
            team_id=self.team_id)


def get_project_rolling_release(project_id: Optional[_builtins.str] = None,
                                team_id: Optional[_builtins.str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectRollingReleaseResult:
    """
    Data source for a Vercel project rolling release configuration.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_project(name="example-project")
    example_get_project_rolling_release = vercel.get_project_rolling_release(project_id=example.id)
    ```


    :param _builtins.str project_id: The ID of the project.
    :param _builtins.str team_id: The ID of the Vercel team.
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getProjectRollingRelease:getProjectRollingRelease', __args__, opts=opts, typ=GetProjectRollingReleaseResult).value

    return AwaitableGetProjectRollingReleaseResult(
        advancement_type=pulumi.get(__ret__, 'advancement_type'),
        id=pulumi.get(__ret__, 'id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        stages=pulumi.get(__ret__, 'stages'),
        team_id=pulumi.get(__ret__, 'team_id'))
def get_project_rolling_release_output(project_id: Optional[pulumi.Input[_builtins.str]] = None,
                                       team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectRollingReleaseResult]:
    """
    Data source for a Vercel project rolling release configuration.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_project(name="example-project")
    example_get_project_rolling_release = vercel.get_project_rolling_release(project_id=example.id)
    ```


    :param _builtins.str project_id: The ID of the project.
    :param _builtins.str team_id: The ID of the Vercel team.
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getProjectRollingRelease:getProjectRollingRelease', __args__, opts=opts, typ=GetProjectRollingReleaseResult)
    return __ret__.apply(lambda __response__: GetProjectRollingReleaseResult(
        advancement_type=pulumi.get(__response__, 'advancement_type'),
        id=pulumi.get(__response__, 'id'),
        project_id=pulumi.get(__response__, 'project_id'),
        stages=pulumi.get(__response__, 'stages'),
        team_id=pulumi.get(__response__, 'team_id')))
